'*************************************************************************
'Contents of this file are (C)Copyright 2020 by Circuit Check Inc.  Any use of
'the contents of this file without an explicit license from Circuit Check Inc
'is THEFT.  Copyright violators will be prosecuted.
'
'        File : dio3750.vb
'        Type : Class
'    Language : Visual Basic
'    Revision : 1.0
'      Author : M. van Meeteren
'        Date : 011320
' Description : Interface class for a DIO card in a 3706A chassis
'
'*************************************************************************

Imports Keithley.Ke37XX.Interop

Friend Class DIO_Keithley3750
  Inherits DIO_Class

  Private Const NumDIOPorts As Integer = 5
  Private Mainframe As DMM_Keithley3706A

  Friend Sub New(ByVal Index As Integer, ByVal INIFileName As String, ByVal MyDMM As DMM_Class)
    ' get card descriptions
    Dim Description As String = String.Empty
    Dim Serial As String = String.Empty
    Dim Firmware As String = String.Empty
    Dim sAddress As String
    Dim DontCare As Boolean = True

    ' tell base device class we're a hosted card, used for addressing
    HostedCard(1000)

    ' get parent DMM type
    If (MyDMM.DMM_Type <> DMM_Class.DMMType.dmmKeithley3706A) Then
      DeviceError("Incorrect DMM type for 3750")
      Return
    End If
    Mainframe = CType(MyDMM, DMM_Keithley3706A)

    ' read address
    If Not ReadDeviceAndAddress("DIO" & Index.ToString, INIFileName) Then Return

    Try
      With Mainframe.KeithleyRack.System.Card
        ' make sure card is present
        .GetCardIdentification(CardSlot, MyDevice, Description, Firmware, Serial)
        If Not (MyDevice.ToUpper = "3750") Then
          DeviceError("3750 Card not found in slot " & CardSlot.ToString)
          Return
        End If
      End With
    Catch ex As Exception
      DeviceException("Keithley Rack Supply card exception: " & ex.Message)
      Return
    End Try

    Try
      Dim PortNum As Integer

      ' set up the ports for the DIO card
      For PortNum = 0 To NumDIOPorts - 1
        sAddress = (MyAddress + PortNum + 1).ToString
        Mainframe.KeithleyRack.DIO.SetMode(sAddress, Ke37XXDIOModeEnum.Ke37XXDIOModeInput)
      Next
    Catch ex As Exception
      DeviceException("Keithley Rack InitDIO parameter exception: " & ex.Message)
      Return
    End Try
    InittedOK = True
  End Sub

  Friend Overrides Function TextChannelList() As String()
    Dim ReturnStrings(0) As String
    Dim Base As Integer = Mainframe.BaseChannel + MyAddress
    Dim LoAddr As Integer = Base + 1
    Dim HiAddr As Integer = Base + NumDIOPorts

    ReturnStrings(0) = LoAddr.ToString & " - " & HiAddr.ToString & " DIO Keithley 3750"
    Return ReturnStrings
  End Function

  Friend Overrides Function ReadByte(ByVal Channel As Integer, ByRef Value As Byte) As Boolean
    Dim dValue As Double

    ReadByte = False
    Value = &HFF  ' simulation mode
    If Not InittedOK Then
      DeviceError("DIO Not Initialized")
      Exit Function
    End If

    Channel -= Mainframe.BaseChannel
    ' check cache
    Try
      dValue = Mainframe.KeithleyRack.Channel.ReadSingleChannel(Channel.ToString)
      Value = CByte(dValue)
      If Not CheckError(Mainframe.CardReadError(Equip_Error)) Then Exit Function
    Catch ex As Exception
      DeviceException("Keithley Rack ReadByte DIO exception: " & ex.Message)
      Exit Function
    End Try
    Return True
  End Function

End Class
