﻿'*************************************************************************
'Contents of this file are (C)Copyright 2019 by Circuit Check Inc.  Any use of
'the contents of this file without an explicit license from Circuit Check Inc
'is THEFT.  Copyright violators will be prosecuted.
'
'        File : dmm3706a.vb
'        Type : Class
'    Language : Visual Basic
'    Revision : 1.0
'      Author : M. van Meeteren
'        Date : 122319
' Description : Class for interfacing to Keithley 3706A rack
'
'*************************************************************************

Imports Keithley.Ke37XX.Interop
Imports System.Threading

Friend Class DMM_Keithley3706A
  Inherits DMM_Class

  Friend KeithleyRack As Ke37XX = Nothing

  Friend Overrides Function DMM_Type() As DMMType
    Return DMMType.dmmKeithley3706A
  End Function

  Friend Sub New(ByVal Index As Integer, ByVal INIFileName As String)
    Dim standardInitOptions As String = "QueryInstrStatus=true, Simulate=false"
    ' Dim INIParam As String

    ' read device and baseaddress
    If Not ReadDeviceAndAddress("DMM" & Index.ToString, INIFileName) Then Return

    ' special case, the first address on a 3706A is 1001, but the card addresses start 
    ' at 1001 so we subtract 1000 so the "base address" for this DMM is right
    MyAddress -= 1000

    ' Initialize the main rack first
    Try
      ' Create the object
      KeithleyRack = New Ke37XX

      ' Open the I/O session with the driver
      KeithleyRack.Initialize(MyDevice, True, True, standardInitOptions)

      ' Reset Mux card 
      KeithleyRack.Utility.Reset()

      ' get actual model
      Dim Description As String = String.Empty
      Description = KeithleyRack.Identity.InstrumentModel

      ' set DMM name
      SetDMMName("Keithley 3700", Description)

      InittedOK = KeithleyRack.Initialized And CheckError(FlushInstrumentErrors(Equip_Error))

    Catch ex As Exception
      InittedOK = False
      DeviceException("Keithley 3700 init exception: " + ex.Message)
      CheckError(ReadInstrumentError(Equip_Error))
      Equip_Error = "Init Exception : " & ex.Message & " " & Equip_Error
      If KeithleyRack.Initialized Then KeithleyRack.Close()
      KeithleyRack = Nothing
      Exit Sub
    End Try
  End Sub

  Friend Overrides Sub CloseDevice()
    If KeithleyRack IsNot Nothing Then
      If KeithleyRack.Initialized Then KeithleyRack.Close()
      KeithleyRack = Nothing
    End If
  End Sub

  Friend Function CardReadError(ByRef CardError As String) As Boolean
    ' this is for use by cards that plug into the mainframe to get around the fact that
    ' ReadInstrumentError is a protected function
    Return ReadInstrumentErrors(CardError)
  End Function

  Protected Overrides Sub ErrorQuery(ByRef errCode As Integer, ByRef errMsg As String)
    KeithleyRack.Utility.ErrorQuery(errCode, errMsg)
  End Sub

End Class
